@@ -2,7 +2,7 @@ import asyncio
 import inspect
 import time
 from contextlib import asynccontextmanager
-from typing import Any, AsyncIterator, Awaitable, Dict, Optional, cast
+from typing import Any, AsyncIterator, Dict, Optional, cast
 
 import aiobotocore
 import aiobotocore.client
@@ -103,7 +103,7 @@ class ClientConnector(object):
             create_client_func = session._create_client if hasattr(session, "_create_client") else session.create_client
             client_value = create_client_func(service_name, config=config, **credentials)
             if inspect.isawaitable(client_value):
-                client = await cast(Awaitable, client_value)
+                client = await client_value
             else:
                 client = client_value
 
@@ -240,9 +240,11 @@ class ClientConnector(object):
                     raise
                 await asyncio.sleep(0.1)
 
-        if not self.get_client(alias_name or service_name or ""):
+        client_name = alias_name or service_name or ""
+
+        if not self.get_client(client_name):
             await self.create_client(alias_name, credentials, service_name)
-        client = self.get_client(alias_name or service_name or "")
+        client = self.get_client(client_name)
 
         try:
             yield client
@@ -254,7 +256,7 @@ class ClientConnector(object):
             await self.close_client(client=client, fast=True)
             raise
         except (aiohttp.client_exceptions.ServerDisconnectedError, asyncio.TimeoutError, RuntimeError):
-            await self.reconnect_client(client=client)
+            await self.reconnect_client(client_name, client=client)
             raise
         except botocore.exceptions.ClientError as e:
             error_message = str(e)
