@@ -32,7 +32,7 @@ class ServiceImporter(object):
             sys.path.insert(0, os.path.dirname(os.path.dirname(file_path)))
             if file_path.endswith(".py") and not os.path.isfile(file_path):
                 raise OSError("No such service file")
-            elif not file_path.endswith(".py") and not os.path.isfile("{}.py".format(file_path)):
+            if not file_path.endswith(".py") and not os.path.isfile("{}.py".format(file_path)):
                 raise OSError("No such service file")
             try:
                 spec: Any = importlib.util.find_spec(
